#!/usr/bin/env python
from __future__ import division, absolute_import, print_function
"""
Provide version number for partialwrap library.

This module was written by Matthias Cuntz while at Institut National de
Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
France.

Copyright (c) 2016-2020 Matthias Cuntz - mc (at) macu (dot) de
Released under the MIT License; see LICENSE file for details.

* Written Mar 2020 by Matthias Cuntz (mc (at) macu (dot) de)
* v1.0, initial PyPI commit, Jun 2020, Matthias Cuntz
* v1.0.1, trigger zenodo, Jun 2020, Matthias Cuntz
* v1.1, make flake8 compliant, Dec 2020, Matthias Cuntz
* v1.2, remove scipy.optimize from tests, Dec 2020, Matthias Cuntz
* v1.3, allow non-numeric parameters, May 2021, Matthias Cuntz

.. moduleauthor:: Matthias Cuntz
"""

__author__  = "Matthias Cuntz"
__version__ = "1.3"
